==> ffmpeg2theora-0.0.2.tgz: package/lib/job.js <==
var events = require('events');
var util = require('util');

var spawn = require('child_process').spawn;

String.prototype.trim = function() {
	return this.replace(/^\s+|\s+$/g, '');
};
var Job = module.exports = function(options) {

	this.source = options.source;
	this.dest = options.dest;
	this.contaner = options.contaner || 'mp4';
	this.videoQuality = options.videoQuality;
	this.audioQuality = options.audioQuality;
	this.info = {};
	this.error;
	this.rawPipe = '';
	this.state = 0;
	// 0 == not runnung, 1 == ready, 2 == running, 3 == done.

	events.EventEmitter.call(this);

	return this;
};
// So will act like an event emitter
util.inherits(Job, events.EventEmitter);

Job.prototype.run = function() {
	if(this.state == 2 || this.state == 3) {
		return
	}
	var options = [];

	options.push(this.source)
	options.push('-o')
	options.push(this.dest)
	options.push('--videoquality')
	options.push(this.videoQuality)
	options.push('--audioquality')
	options.push(this.audioQuality)

	this.state = 2;

	var encode = spawn('ffmpeg2theora', options);

	var rawPipe = this.rawPipe;
	encode.stderr.setEncoding('utf8');
	encode.stderr.on('data', function(data) {
		//console.log(data)
		self.rawPipe = data;
	});
	encode.on('exit', function(code) {
		self.state = 4;
		if(code === 0) {
			self.emit('done')
		} else {
			self.emit('error')
			self.error = {
				code : code,
				message : 'Code error.'
			}
		}
	});
	var self = this;
	setTimeout(function() {
		self.ping()
	}, 5000)
	return this;
}
Job.prototype.ping = function() {
	console.log('JOB PING')
	console.log(this.info)
	if(this.state === 2) {
		var rawPipe = this.rawPipe
		try {
			var remaining = /time remaining: (([0-9]{2}):([0-9]{2}):([0-9]{2}))/.exec(rawPipe)
			if(remaining) {
				remaining = remaining[1]
			}
			var time = /(([0-9]+):([0-9]{2}):([0-9]{2}).([0-9]+))/.exec(rawPipe);
			
			if(time) {
				time = time[1]
			}
			var audio = /audio: ([0-9]+)kbps/.exec(rawPipe);
			
			if(audio) {
				audio = audio[1]
			}
			var video = /video: ([0-9]+)kbps/.exec(rawPipe);
			
			if(video) {
				video = video[1]
			}
			this.info = {
				time : time,
				audio : audio,
				video : video,
				remaining : remaining
			}
		} catch (err) {
			this.info = {
				error : err,
				nowTime : Date.now()
			}
		}
		var self = this;
		setTimeout(function() {
			self.ping()
		}, 5000)
	}

}

==> ffmpeg2theora-0.0.3.tgz: package/lib/job.js <==
var events = require('events');
var util = require('util');

var spawn = require('child_process').spawn;

String.prototype.trim = function() {
	return this.replace(/^\s+|\s+$/g, '');
};
var Job = module.exports = function(options) {

	this.source = options.source;
	this.dest = options.dest;
	this.contaner = options.contaner || 'mp4';
	this.videoQuality = options.videoQuality;
	this.audioQuality = options.audioQuality;
	this.info = {};
	this.error;
	this.rawPipe = '';
	this.state = 0;
	// 0 == not runnung, 1 == ready, 2 == running, 3 == done.

	events.EventEmitter.call(this);

	return this;
};
// So will act like an event emitter
util.inherits(Job, events.EventEmitter);

Job.prototype.run = function() {
	if(this.state == 2 || this.state == 3) {
		return
	}
	var options = [];

	options.push(this.source)
	options.push('-o')
	options.push(this.dest)
	options.push('--videoquality')
	options.push(this.videoQuality)
	options.push('--audioquality')
	options.push(this.audioQuality)

	this.state = 2;

	var encode = spawn('ffmpeg2theora', options);

	var rawPipe = this.rawPipe;
	encode.stderr.setEncoding('utf8');
	encode.stderr.on('data', function(data) {
		//console.log(data)
		self.rawPipe = data;
	});
	encode.on('exit', function(code) {
		self.state = 4;
		if(code === 0) {
			self.emit('done')
		} else {
			self.emit('error')
			self.error = {
				code : code,
				message : 'Code error.'
			}
		}
	});
	var self = this;
	setTimeout(function() {
		self.ping()
	}, 5000)
	return this;
}
Job.prototype.ping = function() {
	console.log('JOB PING')
	//console.log(this.info)
	if(this.state === 2) {
		var rawPipe = this.rawPipe
		try {
			var remaining = /time remaining: (([0-9]{2}):([0-9]{2}):([0-9]{2}))/.exec(rawPipe)
			if(remaining) {
				remaining = remaining[1]
			}
			var time = /(([0-9]+):([0-9]{2}):([0-9]{2}).([0-9]+))/.exec(rawPipe);
			
			if(time) {
				time = time[1]
			}
			var audio = /audio: ([0-9]+)kbps/.exec(rawPipe);
			
			if(audio) {
				audio = audio[1]
			}
			var video = /video: ([0-9]+)kbps/.exec(rawPipe);
			
			if(video) {
				video = video[1]
			}
			this.info = {
				time : time,
				audio : audio,
				video : video,
				remaining : remaining
			}
		} catch (err) {
			this.info = {
				error : err,
				nowTime : Date.now()
			}
		}
		var self = this;
		setTimeout(function() {
			self.ping()
		}, 5000)
	}

}
